==> haskell-tasty-1.4.2.3-16-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tasty
version:              1.4.2.3
visibility:           public
id:                   tasty-1.4.2.3-LfCoZZg5ttU5VpHV083ruq
key:                  tasty-1.4.2.3-LfCoZZg5ttU5VpHV083ruq
license:              MIT
maintainer:           Roman Cheplyaka <roma@ro-che.info>
author:               Roman Cheplyaka <roma@ro-che.info>
homepage:             https://github.com/UnkindPartition/tasty
synopsis:             Modern and extensible testing framework
description:
    Tasty is a modern testing framework for Haskell.
    It lets you combine your unit tests, golden
    tests, QuickCheck/SmallCheck properties, and any
    other types of tests into a single test suite.

category:             Testing
abi:                  5d63e549ae0a4b29b02d5ece9bd1e6e2
exposed:              True
exposed-modules:
    Test.Tasty Test.Tasty.Ingredients Test.Tasty.Ingredients.Basic
    Test.Tasty.Ingredients.ConsoleReporter Test.Tasty.Options
    Test.Tasty.Patterns.Eval Test.Tasty.Patterns.Parser
    Test.Tasty.Patterns.Printer Test.Tasty.Patterns.Types
    Test.Tasty.Providers Test.Tasty.Providers.ConsoleFormat
    Test.Tasty.Runners

hidden-modules:
    Control.Concurrent.Async Test.Tasty.Parallel Test.Tasty.Core
    Test.Tasty.Options.Core Test.Tasty.Options.Env Test.Tasty.Patterns
    Test.Tasty.Patterns.Expr Test.Tasty.Run Test.Tasty.Runners.Reducers
    Test.Tasty.Runners.Utils Test.Tasty.CmdLine
    Test.Tasty.Ingredients.ListTests
    Test.Tasty.Ingredients.IncludingOptions

import-dirs:          /usr/lib/ghc-9.0.2/site-local/tasty-1.4.2.3
library-dirs:         /usr/lib/ghc-9.0.2/site-local/tasty-1.4.2.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty
hs-libraries:         HStasty-1.4.2.3-LfCoZZg5ttU5VpHV083ruq
depends:
    ansi-terminal-0.11.3-4sOL9w5QIphDlJIIpaWFJL base-4.15.1.0
    clock-0.8.3-Fv0D0yBvZ0lAMnhb6tqs3B containers-0.6.4.1
    optparse-applicative-0.16.1.0-BKNPip5PGw2CnbOiekISfW stm-2.5.0.0
    tagged-0.8.6.1-79gYUUazit6EfoPS33FHdR transformers-0.5.6.2
    unbounded-delays-0.1.1.1-KU4Jg1KyC6i76f9JqBmZ6Z unix-2.7.2.2
    wcwidth-0.0.2-1XgtniWuRB3EWTQgBV39VT

haddock-interfaces:   /usr/share/doc/haskell-tasty/html/tasty.haddock
haddock-html:         /usr/share/doc/haskell-tasty/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-1.4.2.3-37-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tasty
version:              1.4.2.3
visibility:           public
id:                   tasty-1.4.2.3-GZeL6u6d7NUB6KDbi0bUp3
key:                  tasty-1.4.2.3-GZeL6u6d7NUB6KDbi0bUp3
license:              MIT
maintainer:           Roman Cheplyaka <roma@ro-che.info>
author:               Roman Cheplyaka <roma@ro-che.info>
homepage:             https://github.com/UnkindPartition/tasty
synopsis:             Modern and extensible testing framework
description:
    Tasty is a modern testing framework for Haskell.
    It lets you combine your unit tests, golden
    tests, QuickCheck/SmallCheck properties, and any
    other types of tests into a single test suite.

category:             Testing
abi:                  e34939384c6c8568650b3553f1322dde
exposed:              True
exposed-modules:
    Test.Tasty Test.Tasty.Ingredients Test.Tasty.Ingredients.Basic
    Test.Tasty.Ingredients.ConsoleReporter Test.Tasty.Options
    Test.Tasty.Patterns.Eval Test.Tasty.Patterns.Parser
    Test.Tasty.Patterns.Printer Test.Tasty.Patterns.Types
    Test.Tasty.Providers Test.Tasty.Providers.ConsoleFormat
    Test.Tasty.Runners

hidden-modules:
    Control.Concurrent.Async Test.Tasty.Parallel Test.Tasty.Core
    Test.Tasty.Options.Core Test.Tasty.Options.Env Test.Tasty.Patterns
    Test.Tasty.Patterns.Expr Test.Tasty.Run Test.Tasty.Runners.Reducers
    Test.Tasty.Runners.Utils Test.Tasty.CmdLine
    Test.Tasty.Ingredients.ListTests
    Test.Tasty.Ingredients.IncludingOptions

import-dirs:          /usr/lib/ghc-9.0.2/site-local/tasty-1.4.2.3
library-dirs:         /usr/lib/ghc-9.0.2/site-local/tasty-1.4.2.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty
hs-libraries:         HStasty-1.4.2.3-GZeL6u6d7NUB6KDbi0bUp3
depends:
    ansi-terminal-0.11.3-DPig6ZRtI9RCB3cEnEW0u0 base-4.15.1.0
    clock-0.8.3-5r0WlOZbhJAFFaUNBQokGT containers-0.6.4.1
    optparse-applicative-0.17.0.0-8GMV2oMnHRr69sgTN9Km0U stm-2.5.0.0
    tagged-0.8.6.1-79gYUUazit6EfoPS33FHdR transformers-0.5.6.2
    unbounded-delays-0.1.1.1-KU4Jg1KyC6i76f9JqBmZ6Z unix-2.7.2.2
    wcwidth-0.0.2-1XgtniWuRB3EWTQgBV39VT

haddock-interfaces:   /usr/share/doc/haskell-tasty/html/tasty.haddock
haddock-html:         /usr/share/doc/haskell-tasty/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
